@@ -24,17 +24,7 @@ def perform_transformation(instances, field_names=None):
 
             for destination_field_name, transformation in destination_dict.items():
                 destination_field = getattr(instance, destination_field_name)
-                try:
-                    new_image = transformation(original_field)
-                except:
-                    new_image = None
-                    logger.error(
-                        'The image on {} cannot be transformed from {} -> {}. None has been saved to the resulting field'.format(
-                            instance,
-                            original_field_name,
-                            destination_field_name
-                        )
-                    )
+                new_image = transformation(original_field)
                 if new_image:
                     destination_field.save(
                         original_name,
@@ -42,9 +32,17 @@ def perform_transformation(instances, field_names=None):
                         save=False
                     )
                 else:
+                    logger.error(
+                        'The image on {0} was not transformed from {1} -> {2}'.format(
+                            instance,
+                            original_field_name,
+                            destination_field_name
+                        )
+                    )
                     if destination_field:
                         destination_field.delete(
                             save=False
                         )
                 updated_fields.append(destination_field_name)
-        instance.save(update_fields=updated_fields)
+        if updated_fields:
+            instance.save(update_fields=updated_fields)
